@@ -104,7 +104,7 @@ dgr <- function(graph, cmode="degree",
     } else {
       ans - Matrix::diag(graph)
     }
-  }
+  } else ans
 
   return(matrix(ans, ncol=1))
 }
@@ -247,7 +247,7 @@ dgr.array <- function(graph, cmode, undirected, self, valued) {
 #' \code{\link{toa_mat}}
 #' @param attrs Either a character scalar (if \code{graph} is diffnet),
 #' or a numeric matrix of size \eqn{n\times T}{n * T}. Weighting for each time, period (see details).
-#' @param alt.graph Either a dynamic graph that should be used instead of \code{graph},
+#' @param alt.graph Either a graph that should be used instead of \code{graph},
 #' or \code{"se"} (see details).
 #' @param outgoing Logical scalar. When \code{TRUE}, computed using outgoing ties.
 #' @param normalized Logical scalar. When \code{TRUE}, the exposure will be between zero
@@ -280,6 +280,9 @@ dgr.array <- function(graph, cmode, undirected, self, valued) {
 #' be equal to \code{TRUE}, this check is run automatically when running the
 #' model using structural equivalence.
 #'
+#' If the \code{alt.graph} is static, then the function will warn about it
+#' and will recycle the graph to compute exposure at each time point.
+#'
 #' \bold{An important remark} is that when calculating \bold{structural equivalence} the
 #' function \bold{assumes that this is to be done to the entire graph} regardless of
 #' disconnected communities (as in the case of the medical innovations
@@ -370,7 +373,7 @@ dgr.array <- function(graph, cmode, undirected, self, valued) {
 #' test <- summary(medInnovationsDiffNet, no.print=TRUE) ==
 #'    summary(diffnet, no.print=TRUE)
 #'
-#' stopifnot(all(test))
+#' stopifnot(all(test[!is.na(test)]))
 #'
 #' # METHOD 2: Using the 'groupvar' argument
 #' # Further, we can compare this with using the groupvar
@@ -379,7 +382,7 @@ dgr.array <- function(graph, cmode, undirected, self, valued) {
 #'
 #' # These should be equivalent
 #' test <- diffnet[["expo_se", as.df=TRUE]] == diffnet[["expo_se2", as.df=TRUE]]
-#' stopifnot(all(test))
+#' stopifnot(all(test[!is.na(test)]))
 #'
 #' # METHOD 3: Computing exposure, rbind and then adding it to the diffnet object
 #' expo_se3 <- NULL
@@ -397,7 +400,7 @@ dgr.array <- function(graph, cmode, undirected, self, valued) {
 #' diffnet[["expo_se3"]] <- expo_se3
 #'
 #' test <- diffnet[["expo_se", as.df=TRUE]] == diffnet[["expo_se3", as.df=TRUE]]
-#' stopifnot(all(test))
+#' stopifnot(all(test[!is.na(test)]))
 #'
 #'
 #' # METHOD 4: Using the groupvar in struct_equiv
@@ -412,7 +415,7 @@ dgr.array <- function(graph, cmode, undirected, self, valued) {
 #' diffnet[["expo_se4"]] <- exposure(diffnet, alt.graph=se, valued=TRUE)
 #'
 #' test <- diffnet[["expo_se", as.df=TRUE]] == diffnet[["expo_se4", as.df=TRUE]]
-#' stopifnot(all(test))
+#' stopifnot(all(test[!is.na(test)]))
 #'
 #'
 #'
@@ -514,6 +517,15 @@ exposure <- function(graph, cumadopt, attrs = NULL, alt.graph=NULL,
       se
 
     } else {
+      # In the case of static nets
+      if (inherits(alt.graph, "matrix"))
+        alt.graph <- methods::as(alt.graph, "dgCMatrix")
+
+      if (inherits(alt.graph, "dgCMatrix")) {
+        warning("When -alt.graph- is static, will be repeated \"t\" times to fit the data.")
+        alt.graph <- lapply(1:length(graph), function(x) alt.graph)
+      }
+
       if (!valued)
         warning("The -alt.graph- will be treated as 0/1 graph (value=FALSE).")
       alt.graph
@@ -1121,3 +1133,112 @@ vertex_mahalanobis_dist <- function(graph, X, S) {
 
   return(ans)
 }
+
+
+#' Useful functions for binary comparisons in sparse matrices
+#'
+#' @details ASD
+#'
+#' @name binary-functions
+NULL
+
+#' Non-zero element-wise comparison between two sparse matrices
+#'
+#' Taking advantage of matrix sparseness, the function only evaluates
+#' \code{fun} between pairs of elements of \code{A} and \code{B} where
+#' either \code{A} or \code{B} have non-zero values. This can be helpful
+#' to implement other binary operators between sparse matrices that may
+#' not be implemented in the \pkg{Matrix} package.
+#'
+#' @param A A matrix of size \code{n*m} of class \code{\link[Matrix:dgCMatrix-class]{dgCMatrix}}.
+#' @param B A matrix of size \code{n*m} of class \code{\link[Matrix:dgCMatrix-class]{dgCMatrix}}.
+#' @param fun A function that receives 2 arguments and returns a scalar.
+#'
+#' @details Instead of comparing element by element, the function
+#' loops through each matrix non-zero elements to make the comparisons, which
+#' in the case of sparse matrices can be more efficient (faster). Algorithmically
+#' it can be described as follows:
+#'
+#' \preformatted{
+#' # Matrix initialization
+#' init ans[n,m];
+#'
+#' # Looping through non-zero elements of A
+#' for e_A in E_A:
+#'   ans[e_A] = fun(A[e_A], B[e_A])
+#'
+#' # Looping through non-zero elements of B and applying the function
+#' # in e_B only if it was not applied while looping in E_A.
+#' for e_B in E_B:
+#'   if (ans[e_B] == Empty)
+#'     ans[e_B] = fun(A[e_B], B[e_B])
+#'
+#' }
+#'
+#' \code{compare_matrix} is just an alias for \code{matrix_compare}.
+#'
+#' @return An object of class \code{dgCMatrix} of size \code{n*m}.
+#' @export
+#' @examples
+#' # These two should yield the same results -----------------------------------
+#'
+#' # Creating two random matrices
+#' set.seed(89)
+#' A <- rgraph_ba(t = 9, m = 4)
+#' B <- rgraph_ba(t = 9, m = 4)
+#' A;B
+#'
+#' # Comparing
+#' ans0 <- matrix_compare(A,B, function(a,b) (a+b)/2)
+#'
+#' ans1 <- matrix(0, ncol=10, nrow=10)
+#' for (i in 1:10)
+#'   for (j in 1:10)
+#'     ans1[i,j] <- mean(c(A[i,j], B[i,j]))
+#'
+#' # Are these equal?
+#' all(ans0[] == ans1[]) # Should yield TRUE
+#'
+#' # More elaborated example (speed) -------------------------------------------
+#' \dontrun{
+#'
+#' set.seed(123123123)
+#' A <- rgraph_ba(t = 5e3, m = 2)
+#' B <- rgraph_ba(t = 5e3, m = 2)
+#'
+#' Am <- as.matrix(A)
+#' Bm <- as.matrix(B)
+#'
+#' compfun <- function(a,b)
+#'   ifelse(a > b, a, b)
+#'
+#' microbenchmark::microbenchmark(
+#'   diffnet = matrix_compare(A, B, compfun),
+#'   R       = ifelse(Am > Bm, Am, Bm),
+#'   times   = 10
+#' )
+#' # Unit: milliseconds
+#' #    expr       min        lq      mean    median       uq      max neval cld
+#' # diffnet  349.1731  350.8051  360.7358  353.5629  354.787  432.450    10  a
+#' #       R 1333.9946 1406.1971 2249.7132 1515.0995 1976.028 7691.428    10   b
+#'
+#' }
+matrix_compare <- function(A, B, fun) {
+
+  # Checking objects class
+  if (!inherits(A, c("dgCMatrix")))
+    stop("-A- must be a dgCMatrix.")
+
+  if (!inherits(B, c("dgCMatrix")))
+    stop("-B- must be a dgCMatrix.")
+
+  if (any(dim(A) != dim(B)))
+    stop("-A- and -B- must have the same dimmension.")
+
+  matrix_compareCpp(A, B, fun)
+}
+
+#' @rdname matrix_compare
+#' @export
+compare_matrix <- matrix_compare
+
