@@ -28,8 +28,14 @@ double st_greaterequal(double y0, double y1);
 double st_smaller(double y0, double y1);
 double st_smallerequal(double y0, double y1);
 double st_equal(double y0, double y1);
+double st_min(double y0, double y1);
+double st_max(double y0, double y1);
+double st_mean(double y0, double y1);
 
 void st_getfun(std::string funname, funcPtr & fun);
-NumericVector complete_cases_graph(arma::sp_mat & graph, NumericVector & x);
+
+arma::sp_mat bootnet_fillself(
+    arma::sp_mat & graph, const IntegerVector & index, const NumericVector & E
+  );
 
 #endif
