@@ -13,7 +13,9 @@ arma::sp_mat rgraph_er_cpp(
     int n=10, double p = 0.3, bool undirected=true,
     bool weighted=false, bool self=false) {
 
-  arma::sp_mat graph(n, n);
+  std::vector< unsigned int > source;
+  std::vector< unsigned int > target;
+  std::vector< double > vals;
 
   for(int i=0;i<n;i++) {
     // Checling user interrup
@@ -29,19 +31,39 @@ arma::sp_mat rgraph_er_cpp(
       if (!self && (i==j)) continue;
 
       /* Setting the value of the tie */
-      double w = unif_rand();
+      double w = unif_rand(); //R::runif(0, 1);
       if (w > (1-p)) {
         if (!weighted) w=1.0;
-        graph.at(i,j) = w;
-        if (undirected) graph.at(j,i) = w;
+
+        source.push_back(i);
+        target.push_back(j);
+        vals.push_back(w);
+
+        // Adding the mirror
+        if (undirected) {
+          source.push_back(j);
+          target.push_back(i);
+          vals.push_back(w);
+        }
       }
     }
   }
 
+  // Storing the data as sparse matrix
+  arma::sp_mat graph(
+      // Creating a umat
+      arma::join_cols(
+        arma::conv_to< arma::urowvec >::from(source),
+        arma::conv_to< arma::urowvec >::from(target)
+    ),
+    // Values
+    arma::conv_to< arma::colvec >::from(vals),
+    // Size, sorting and checking for zeros
+    n, n, true, false);
+
   return graph;
 }
 
-
 // -----------------------------------------------------------------------------
 //
 // Small world graphs
@@ -468,6 +490,24 @@ arma::sp_mat permute_graph_cpp(const arma::sp_mat & x,
 //
 // -----------------------------------------------------------------------------
 
+// Checking if integer i is in x.
+int does_exists(const std::vector< unsigned int > & x, unsigned int val) {
+  int ans = -1;
+
+  // If the vector is empty, then nothing to see here
+  if (x.size() == 0)
+    return ans;
+
+  for (unsigned int i = 0; i < x.size(); i++) {
+    if (x.at(i) != val) continue;
+
+    ans = i;
+    break;
+  }
+
+  return ans;
+}
+
 // [[Rcpp::export]]
 arma::sp_mat rgraph_ba_cpp(
     const arma::sp_mat & graph,
@@ -480,12 +520,21 @@ arma::sp_mat rgraph_ba_cpp(
   int n = m0 + t;
 
   // Creating new graph and vector of degree
-  arma::sp_mat graph_new(n,n);
-  graph_new.submat(0,0,m0-1, m0-1) = graph;
-
   arma::colvec dgr_new(n, arma::fill::zeros);
   dgr_new.subvec(0, m0-1) = dgr;
 
+  std::vector< std::vector<unsigned int> > source(n);
+  std::vector< std::vector<double> > value(n);
+
+  // Setting the initial values
+  int nlocations = graph.n_nonzero;
+  arma::sp_mat::const_iterator iter;
+  for (iter = graph.begin(); iter != graph.end(); iter++) {
+    source.at(iter.row()).push_back(iter.col());
+    value.at(iter.row()).push_back(*iter);
+  }
+
+
   // Start the process, K is sum(dgr)
   int K = sum(dgr);
 
@@ -493,7 +542,7 @@ arma::sp_mat rgraph_ba_cpp(
   double randdraw, cump;
 
   // If self=true, then the prob are computed over m0+1, otherwise only over m0
-  int extra = self? 1 : 0;
+  int extra = self? 1 : 0, exists;
   for(int i=0;i<t;i++) {
     // Checling user interrup
     if (i % 1000 == 0)
@@ -514,7 +563,7 @@ arma::sp_mat rgraph_ba_cpp(
 
       // std::cout << j << " Iter, "<< m << " m\n";
       // Random selection
-      randdraw = unif_rand();
+      randdraw = R::runif(0,1); //unif_rand();
 
       // Calculating probabilities of been drawn. -cump- is the cumsum of the
       // probabilities
@@ -532,7 +581,16 @@ arma::sp_mat rgraph_ba_cpp(
 
         // Links to the set of previous vertices
         if (randdraw <= cump) {
-          graph_new.at(m0, k) += 1.0; // , graph_new.at(k, m0) += 1.0
+          exists = does_exists(source.at(m0), k);
+
+          if (exists < 0) {
+            source.at(m0).push_back(k);
+            value.at(m0).push_back(1.0);
+            ++nlocations;
+          } else {
+            ++value.at(m0).at(exists);
+          }
+
           dgr_new.at(k) += 1.0;
 
           // Sumation of degrees
@@ -544,9 +602,27 @@ arma::sp_mat rgraph_ba_cpp(
     ++m0;
   }
 
+  // Now need to coerce into a -sp_mat-
+  arma::umat locations(2, nlocations);
+  arma::colvec values(nlocations);
+
+  int curloc = 0;
+  for (int i = 0; i<n; i++) {
+    for (unsigned int j = 0; j < source.at(i).size(); j++) {
+      locations.at(0, curloc) = i;
+      locations.at(1, curloc) = source.at(i).at(j);
+      values.at(curloc++) = value.at(i).at(j);
+    }
+
+  }
+
+  // Creating the sparse matrix
+  arma::sp_mat graph_new(locations, values, n, n, true, false);
+
   return graph_new;
 }
 
+
 // [[Rcpp::export]]
 arma::sp_mat rgraph_ba_new_cpp(int m0 = 1, int m = 1, int t = 10, bool self=true) {
   int n = m0;
